OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Contrasenya incorrecta",
    "No user supplied" : "No heu proporcionat cap usuari",
    "Authentication error" : "Error d'autenticació",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Sisplau, proporcioneu una contrasenya de recuperació d'administrador, altrament totes les dades d'usuari es perdran",
    "Wrong admin recovery password. Please check the password and try again." : "La contrasenya de recuperació d'administrador és incorrecta. Comproveu-la i torneu-ho a intentar.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "El backend no admet canvis de contrasenya, però la clau de xifrat de l'usuari ha estat actualitzada satisfactòriament.",
    "Unable to change password" : "No es pot canviar la contrasenya",
    "Enabled" : "Activat",
    "Not enabled" : "Desactivat",
    "Federated Cloud Sharing" : "Compartició federada de núvol",
    "A problem occurred, please check your log files (Error: %s)" : "S'ha produït un problema, si us plau revisi els arxius de registre (Error: %s)",
    "Migration Completed" : "Migració completada",
    "Group already exists." : "El grup ja existeix.",
    "Unable to add group." : "No es pot agregar el grup.",
    "Unable to delete group." : "No es pot esborrar el grup.",
    "log-level out of allowed range" : "Nivell d'autenticació fora del rang permès",
    "Saved" : "Desat",
    "test email settings" : "prova l'arranjament del correu",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hi ha hagut un problema en enviar el correu. Revisi la seva configuració. (Error: %s)",
    "Email sent" : "El correu electrónic s'ha enviat",
    "You need to set your user email before being able to send test emails." : "Heu d'establir un nom d'usuari abans de poder enviar correus de prova.",
    "Invalid mail address" : "Adreça de correu invàlida",
    "A user with that name already exists." : "Ja existeix un usuari amb est nom.",
    "Unable to create user." : "No es pot crear el usuari.",
    "Your %s account was created" : "S'ha creat el seu compte %s",
    "Unable to delete user." : "No es pot eliminar l'usuari",
    "Forbidden" : "Prohibit",
    "Invalid user" : "Usuari no vàlid",
    "Unable to change mail address" : "No es pot canviar l'adreça de correu electrònic",
    "Email saved" : "S'ha desat el correu electrònic",
    "Your full name has been changed." : "El vostre nom complet ha canviat.",
    "Unable to change full name" : "No s'ha pogut canviar el nom complet",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Avisos de seguretat i configuració",
    "Sharing" : "Compartir",
    "Server-side encryption" : "Xifrat del costat del servidor",
    "External Storage" : "Emmagatzemament extern",
    "Cron" : "Cron",
    "Email server" : "Servidor de correu electrònic",
    "Log" : "Registre",
    "Tips & tricks" : "Consells i trucs",
    "Updates" : "Actualitzacions",
    "Couldn't remove app." : "No s'ha pogut eliminar l'aplicació",
    "Language changed" : "S'ha canviat l'idioma",
    "Invalid request" : "Sol·licitud no vàlida",
    "Admins can't remove themself from the admin group" : "Els administradors no es poden eliminar del grup admin",
    "Unable to add user to group %s" : "No es pot afegir l'usuari al grup %s",
    "Unable to remove user from group %s" : "No es pot eliminar l'usuari del grup %s",
    "Couldn't update app." : "No s'ha pogut actualitzar l'aplicació.",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Esteu seguir que voleu afegir \"{domain}\" com a un domini de confiança?",
    "Add trusted domain" : "Afegir domini de confiança",
    "Migration in progress. Please wait until the migration is finished" : "Migració en progrés. Si us plau, espereu fins que finalitzi la migració",
    "Migration started …" : "Migració iniciada ...",
    "Sending..." : "Enviant...",
    "Official" : "Oficial",
    "Approved" : "Aprovat",
    "Experimental" : "Experimental",
    "All" : "Tots",
    "No apps found for your version" : "No s'han trobat aplicacions per la seva versió",
    "Update to %s" : "Actualitzar a %s",
    "Please wait...." : "Espereu...",
    "Error while disabling app" : "Error en desactivar l'aplicació",
    "Disable" : "Desactiva",
    "Enable" : "Habilita",
    "Error while enabling app" : "Error en activar l'aplicació",
    "Updating...." : "Actualitzant...",
    "Error while updating app" : "Error en actualitzar l'aplicació",
    "Updated" : "Actualitzada",
    "Uninstalling ...." : "Desintal·lant ...",
    "Error while uninstalling app" : "Error en desinstal·lar l'aplicació",
    "Uninstall" : "Desinstal·la",
    "Valid until {date}" : "Vàlid fins {date}",
    "Delete" : "Esborra",
    "An error occurred: {message}" : "S'ha produït un error: {message}",
    "Select a profile picture" : "Seleccioneu una imatge de perfil",
    "Very weak password" : "Contrasenya massa feble",
    "Weak password" : "Contrasenya feble",
    "So-so password" : "Contrasenya passable",
    "Good password" : "Contrasenya bona",
    "Strong password" : "Contrasenya forta",
    "Groups" : "Grups",
    "Unable to delete {objName}" : "No es pot eliminar {objName}",
    "A valid group name must be provided" : "Heu de facilitar un nom de grup vàlid",
    "deleted {groupName}" : "eliminat {groupName}",
    "undo" : "desfés",
    "no group" : "sense grup",
    "never" : "mai",
    "deleted {userName}" : "eliminat {userName}",
    "add group" : "afegeix grup",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Canviar la contrasenya provocarà pèrdua de dades, perquè la recuperació de dades no està disponible per a aquest usuari",
    "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
    "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
    "A valid email must be provided" : "S'ha de subministrar una adreça de correu electrònic vàlida",
    "__language_name__" : "Català",
    "Unlimited" : "Il·limitat",
    "Personal info" : "Informació personal",
    "Sync clients" : "Sincronitzar clients",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tot (problemes fatals, errors, avisos, informació, depuració)",
    "Info, warnings, errors and fatal issues" : "Informació, avisos, errors i problemes fatals",
    "Warnings, errors and fatal issues" : "Avisos, errors i problemes fatals",
    "Errors and fatal issues" : "Errors i problemes fatals",
    "Fatal issues only" : "Només problemes fatals",
    "None" : "Cap",
    "Login" : "Inici de sessió",
    "Plain" : "Pla",
    "NT LAN Manager" : "Gestor NT LAN",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "S'ha habilitat la configuració de només lectura. Això no permet ajustar algunes configuracions a través de la interfície web. A més, l'arxiu ha de fer-se modificable manualment per a cada actualització.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Aparentment PHP està configurat per mostrar blocs en línia de documentació. Això farà que algunes aplicacions core siguin inaccessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement està provocat per una cau/accelerador com Zend OPcache o eAccelerator.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "El seu servidor està funcionant amb Microsoft Windows. Li recomanem Linux encaridament per gaudir una experiència òptima com a usuari.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "El mòdul de PHP 'fileinfo' no s'ha trobat. Us recomanem que habiliteu aquest mòdul per obtenir millors resultats amb la detecció mime-type.",
    "System locale can not be set to a one which supports UTF-8." : "No s'ha pogut establir cap localització del sistema amb suport per UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Això podria comportar problemes amb alguns caràcters en els noms dels fitxer.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Recomanem fermament que instal·leu els paquets requerits en el vostre sistema per suportar un dels següents idiomes: %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si la seva instal·lació no està situada en l'arrel del domini i usa el sistema cron, pot haver-hi problemes en generar-se els URL. Per evitar-los, configuri l'opció \"overwrite.cli.url\" en el seu arxiu config.php perquè usi la ruta de l'arrel del lloc web de la seva instal·lació (suggeriment: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "No va ser possible executar cronjob via CLI. Han aparegut els següents errors tècnics:",
    "Open documentation" : "Obre la documentació",
    "Allow apps to use the Share API" : "Permet que les aplicacions utilitzin l'API de compartir",
    "Allow users to share via link" : "Permet als usuaris compartir a través d'enllaços",
    "Allow public uploads" : "Permet pujada pública",
    "Enforce password protection" : "Reforça la protecció amb contrasenya",
    "Set default expiration date" : "Estableix la data de venciment",
    "Allow users to send mail notification for shared files" : "Permet als usuaris enviar notificacions de fitxers compartits per correu ",
    "Expire after " : "Venciment després de",
    "days" : "dies",
    "Enforce expiration date" : "Força la data de venciment",
    "Allow resharing" : "Permet compartir de nou",
    "Restrict users to only share with users in their groups" : "Permet als usuaris compartir només amb usuaris del seu grup",
    "Allow users to send mail notification for shared files to other users" : "Permetre als usuaris enviar notificacions per correu electrònic dels arxius compartits a d'altres usuaris",
    "Exclude groups from sharing" : "Exclou grups de compartició",
    "These groups will still be able to receive shares, but not to initiate them." : "Aquests fitxers encara podran rebre compartits, però no podran iniciar-los.",
    "Last cron job execution: %s." : "Última execució de la tasca cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Última execució de la tasca cron: %s. Alguna cosa sembla malament.",
    "Cron was not executed yet!" : "El cron encara no s'ha executat!",
    "Execute one task with each page loaded" : "Executa una tasca per cada paquet carregat",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php està registrat en un servei webcron que fa una crida a cron.php cada 15 minuts a través de http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Fer servir el cron del sistema per cridar el cron.php cada 15 minuts.",
    "Enable server-side encryption" : "Habilitar xifrat en el servidor",
    "Enable encryption" : "Habilitar xifrat",
    "Start migration" : "Iniciar migració",
    "This is used for sending out notifications." : "S'usa per enviar notificacions.",
    "Send mode" : "Mode d'enviament",
    "Encryption" : "Xifrat",
    "From address" : "Des de l'adreça",
    "mail" : "correu electrònic",
    "Authentication method" : "Mètode d'autenticació",
    "Authentication required" : "Es requereix autenticació",
    "Server address" : "Adreça del servidor",
    "Port" : "Port",
    "Credentials" : "Credencials",
    "SMTP Username" : "Nom d'usuari SMTP",
    "SMTP Password" : "Contrasenya SMTP",
    "Store credentials" : "Emmagatzemar credencials",
    "Test email settings" : "Prova l'arranjament del correu",
    "Send email" : "Envia correu",
    "Download logfile" : "Descarregar arxiu de registre",
    "More" : "Més",
    "Less" : "Menys",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "L'arxiu de registre és més gran de 100 MB. La descàrrega pot trigar!",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "S'utilitza SQLite com a base de dades. Per a instal·lacions mes grans es recomana canviar a un altre sistema de base de dades.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'ús de SQLite està desaconsellat especialment quan s'usa el client d'escriptori per sincronitzar els fitxers.",
    "How to do backups" : "Com fer còpies de seguretat",
    "Advanced monitoring" : "Supervisió avançada",
    "Performance tuning" : "Ajust del rendiment",
    "Improving the config.php" : "Millorant el config.php",
    "Theming" : "Tematització",
    "Hardening and security guidance" : "Guia de protecció i seguretat",
    "Version" : "Versió",
    "Developer documentation" : "Documentació para desenvolupadors",
    "Experimental applications ahead" : "A partir d'aquest punt hi ha aplicacions experimentals",
    "Documentation:" : "Documentació:",
    "User documentation" : "Documentació d'usuari",
    "Show description …" : "Mostrar descripció...",
    "Hide description …" : "Amagar descripció...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicació no es pot instal·lar perquè les següents dependències no es compleixen:",
    "Enable only for specific groups" : "Activa només per grups específics",
    "Uninstall App" : "Desinstal·la l'aplicació",
    "Common Name" : "Nom comú",
    "Valid until" : "Valid fins",
    "Issued By" : "Emès Per",
    "Valid until %s" : "Vàlid fins %s",
    "Import root certificate" : "Importa certificat root",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Què tal?,<br><br>aquest missatge és per fer-li saber que ara té uncompte %s.<br><br>El seu nom d'usuari: %s<br>Accedeixi en: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Salut!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hola, què tal?,\n\nAquest missatge és per fer-li saber que ara té un compte %s.\n\n El seu nom d'usuari: %s\nAccedeixi en: %s\n\n",
    "Administrator documentation" : "Documentació d'administrador",
    "Online documentation" : "Documentació en línia",
    "Forum" : "Fòrum",
    "Commercial support" : "Suport comercial",
    "Profile picture" : "Foto de perfil",
    "Upload new" : "Puja'n una de nova",
    "Remove image" : "Elimina imatge",
    "Cancel" : "Cancel·la",
    "Full name" : "Nom complet",
    "No display name set" : "No s'ha establert cap nom para mostrar",
    "Email" : "Correu electrònic",
    "Your email address" : "Correu electrònic",
    "No email address set" : "No s'ha establert cap adreça de correu",
    "You are member of the following groups:" : "Vostè és membre dels següents grups:",
    "Password" : "Contrasenya",
    "Unable to change your password" : "No s'ha pogut canviar la contrasenya",
    "Current password" : "Contrasenya actual",
    "New password" : "Contrasenya nova",
    "Change password" : "Canvia la contrasenya",
    "Language" : "Idioma",
    "Help translate" : "Ajudeu-nos amb la traducció",
    "Name" : "Nom",
    "Username" : "Nom d'usuari",
    "Get the apps to sync your files" : "Obtingueu les aplicacions per sincronitzar els vostres fitxers",
    "Desktop client" : "Client d'escriptori",
    "Android app" : "aplicació para Android",
    "iOS app" : "aplicació para iOS",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Si vol recolzar el projecte\n⇥⇥<a href=\"https://owncloud.org/contribute\"\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\"> unir-se al desenvolupament</a>\n⇥⇥o\n⇥⇥<a href=\"https://owncloud.org/promote\"\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\"> difondre'l !</a>!",
    "Show First Run Wizard again" : "Torna a mostrar l'assistent de primera execució",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desenvolupat per la {communityopen} comunitat ownCloud comunitat{linkclose} , el {githubopen} codi font {linkclose} està llicenciat sota la {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Show storage location" : "Mostra la ubicació del magatzem",
    "Show last log in" : "Mostrar l'últim accés",
    "Show user backend" : "Mostrar backend d'usuari",
    "Send email to new user" : "Enviar correu electrònic al nou usuari",
    "Show email address" : "Mostrar l'adreça de correu electrònic",
    "E-Mail" : "E-mail",
    "Create" : "Crea",
    "Admin Recovery Password" : "Recuperació de contrasenya d'administrador",
    "Enter the recovery password in order to recover the users files during password change" : "Escriviu la contrasenya de recuperació per a poder recuperar els fitxers dels usuaris en canviar la contrasenya",
    "Add Group" : "Afegeix grup",
    "Group" : "Grup",
    "Everyone" : "Tothom",
    "Admins" : "Administradors",
    "Default Quota" : "Quota per defecte",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Escriviu la quota d'emmagatzemament (per ex.: \"512 MB\" o \"12 GB\")",
    "Other" : "Un altre",
    "Full Name" : "Nom complet",
    "Group Admin for" : "Grup Admin per",
    "Quota" : "Quota",
    "Storage Location" : "Ubicació de l'emmagatzemament",
    "User Backend" : "Backend d'usuari",
    "Last Login" : "Últim accés",
    "change full name" : "canvia el nom complet",
    "set new password" : "estableix nova contrasenya",
    "change email address" : "canvi d'adreça de correu electrònic",
    "Default" : "Per defecte"
},
"nplurals=2; plural=(n != 1);");
